==> aliyun-java-sdk-edas-2.16.0-sources.jar: com/aliyuncs/edas/model/v20170801/ListConfigCentersResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.model.v20170801;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.edas.transform.v20170801.ListConfigCentersResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class ListConfigCentersResponse extends AcsResponse {

	private Integer code;

	private String message;

	private List<ListConfigCenters> configCentersList;

	public Integer getCode() {
		return this.code;
	}

	public void setCode(Integer code) {
		this.code = code;
	}

	public String getMessage() {
		return this.message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public List<ListConfigCenters> getConfigCentersList() {
		return this.configCentersList;
	}

	public void setConfigCentersList(List<ListConfigCenters> configCentersList) {
		this.configCentersList = configCentersList;
	}

	public static class ListConfigCenters {

		private String dataId;

		private String group;

		private String id;

		public String getDataId() {
			return this.dataId;
		}

		public void setDataId(String dataId) {
			this.dataId = dataId;
		}

		public String getGroup() {
			return this.group;
		}

		public void setGroup(String group) {
			this.group = group;
		}

		public String getId() {
			return this.id;
		}

		public void setId(String id) {
			this.id = id;
		}
	}

	@Override
	public ListConfigCentersResponse getInstance(UnmarshallerContext context) {
		return	ListConfigCentersResponseUnmarshaller.unmarshall(this, context);
	}
}

==> aliyun-java-sdk-edas-2.44.0-sources.jar: com/aliyuncs/edas/model/v20170801/ListConfigCentersResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.edas.model.v20170801;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.edas.transform.v20170801.ListConfigCentersResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class ListConfigCentersResponse extends AcsResponse {

	private Integer code;

	private String message;

	private String requestId;

	private List<ListConfigCenters> configCentersList;

	public Integer getCode() {
		return this.code;
	}

	public void setCode(Integer code) {
		this.code = code;
	}

	public String getMessage() {
		return this.message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public List<ListConfigCenters> getConfigCentersList() {
		return this.configCentersList;
	}

	public void setConfigCentersList(List<ListConfigCenters> configCentersList) {
		this.configCentersList = configCentersList;
	}

	public static class ListConfigCenters {

		private String dataId;

		private String group;

		private String id;

		private String appName;

		public String getDataId() {
			return this.dataId;
		}

		public void setDataId(String dataId) {
			this.dataId = dataId;
		}

		public String getGroup() {
			return this.group;
		}

		public void setGroup(String group) {
			this.group = group;
		}

		public String getId() {
			return this.id;
		}

		public void setId(String id) {
			this.id = id;
		}

		public String getAppName() {
			return this.appName;
		}

		public void setAppName(String appName) {
			this.appName = appName;
		}
	}

	@Override
	public ListConfigCentersResponse getInstance(UnmarshallerContext context) {
		return	ListConfigCentersResponseUnmarshaller.unmarshall(this, context);
	}
}
